::: evalica.Winner
::: evalica.WINNERS
::: evalica.indexing
::: evalica.matrices
::: evalica.MatricesResult
::: evalica.Result
::: evalica.pairwise_frame
::: evalica.pairwise_scores
::: evalica.__version__
